@@ -11,6 +11,13 @@ use std::sync::Mutex;
 
 use lazy_static::*;
 use log::*;
+use maplit::hashmap;
+use pact_plugin_driver::catalogue_manager::{
+  CatalogueEntry,
+  CatalogueEntryProviderType,
+  CatalogueEntryType,
+  register_core_entries
+};
 use rustls::ServerConfig;
 use serde_json::json;
 use uuid::Uuid;
@@ -44,6 +51,31 @@ lazy_static! {
   /// to serve requests.
   ///
   pub static ref MANAGER: Mutex<Option<ServerManager>> = Mutex::new(Option::None);
+
+  /// Mock server entries to add to the plugin catalogue
+  static ref MOCK_SERVER_CATALOGUE_ENTRIES: Vec<CatalogueEntry> = {
+    let mut entries = vec![];
+    entries.push(CatalogueEntry {
+      entry_type: CatalogueEntryType::INTERACTION,
+      provider_type: CatalogueEntryProviderType::CORE,
+      plugin: None,
+      key: "http".to_string(),
+      values: hashmap!{}
+    });
+    entries.push(CatalogueEntry {
+      entry_type: CatalogueEntryType::INTERACTION,
+      provider_type: CatalogueEntryProviderType::CORE,
+      plugin: None,
+      key: "https".to_string(),
+      values: hashmap!{}
+    });
+    entries
+  };
+}
+
+/// Sets up all the core catalogue entries for mock servers
+pub fn configure_core_catalogue() {
+  register_core_entries(MOCK_SERVER_CATALOGUE_ENTRIES.as_ref());
 }
 
 /// Starts a mock server with the given ID, pact and port number. The ID needs to be unique. A port
@@ -61,7 +93,7 @@ lazy_static! {
 /// - If a mock server is not able to be started
 pub fn start_mock_server(
   id: String,
-  pact: Box<dyn Pact>,
+  pact: Box<dyn Pact + Send + Sync>,
   addr: std::net::SocketAddr
 ) -> Result<i32, String> {
   start_mock_server_with_config(id, pact, addr, MockServerConfig::default())
@@ -83,10 +115,13 @@ pub fn start_mock_server(
 /// - If a mock server is not able to be started
 pub fn start_mock_server_with_config(
   id: String,
-  pact: Box<dyn Pact>,
+  pact: Box<dyn Pact + Send + Sync>,
   addr: std::net::SocketAddr,
   config: MockServerConfig
 ) -> Result<i32, String> {
+  configure_core_catalogue();
+  pact_matching::matchers::configure_core_catalogue();
+
   MANAGER.lock().unwrap()
     .get_or_insert_with(ServerManager::new)
     .start_mock_server_with_addr(id, pact, addr, config)
@@ -109,7 +144,7 @@ pub fn start_mock_server_with_config(
 /// - If a mock server is not able to be started
 pub fn start_tls_mock_server(
   id: String,
-  pact: Box<dyn Pact>,
+  pact: Box<dyn Pact + Send + Sync>,
   addr: std::net::SocketAddr,
   tls: &ServerConfig
 ) -> Result<i32, String> {
@@ -133,11 +168,14 @@ pub fn start_tls_mock_server(
 /// - If a mock server is not able to be started
 pub fn start_tls_mock_server_with_config(
   id: String,
-  pact: Box<dyn Pact>,
+  pact: Box<dyn Pact + Send + Sync>,
   addr: std::net::SocketAddr,
   tls: &ServerConfig,
   config: MockServerConfig
 ) -> Result<i32, String> {
+  configure_core_catalogue();
+  pact_matching::matchers::configure_core_catalogue();
+
   MANAGER.lock().unwrap()
     .get_or_insert_with(ServerManager::new)
     .start_tls_mock_server_with_addr(id, pact, addr, tls, config)
@@ -154,6 +192,9 @@ pub fn create_mock_server(
   pact_json: &str,
   addr: std::net::SocketAddr
 ) -> anyhow::Result<i32> {
+  configure_core_catalogue();
+  pact_matching::matchers::configure_core_catalogue();
+
   match serde_json::from_str(pact_json) {
     Ok(pact_json) => {
       let pact = load_pact_from_json("<create_mock_server>", &pact_json)?;
